@@ -52,7 +52,7 @@ class ReportersRegistry:
             report_gen.pre_run_report(**kwargs)
 
     @classmethod
-    def post_run_report(cls, results, kwargs, run_revoked=False):
+    def post_run_report(cls, results, kwargs):
         if kwargs is None:
             kwargs = {}
 
@@ -103,14 +103,13 @@ class ReportersRegistry:
         for report_gen in cls.get_generators():
             try:
                 logger.debug(f'Running post_run_report for {report_gen}')
-                report_gen.post_run_report(root_id=results, run_revoked=run_revoked, **kwargs)
+                report_gen.post_run_report(root_id=results, **kwargs)
                 logger.debug(f'Completed post_run_report for {report_gen}')
             except Exception:
                 # Failure in one report generator should not impact another
                 logger.error(f'Error in the post_run_report for {report_gen}', exc_info=True)
 
 
-
 def recurse_results_tree(results):
     yield results
     try:
