@@ -537,7 +537,7 @@ class SubmitBaseApp:
             logger.debug("Waited %.1f secs for tracking services to be %s." % (wait_duration, description))
 
     def wait_tracking_services_task_ready(self, timeout=5)->None:
-        self.wait_tracking_services_pred(lambda s: s.ready_for_tasks(), 'ready for tasks', timeout)
+        self.wait_tracking_services_pred(lambda s: s.ready_for_tasks(celery_app=app), 'ready for tasks', timeout)
 
     def wait_tracking_services_release_console_ready(self, timeout=5)->None:
         self.wait_tracking_services_pred(lambda s: s.ready_release_console(), 'ready to release console', timeout)
